..
   SPDX-FileCopyrightText: Copyright DB Netz AG and the pyease contributors
   SPDX-License-Identifier: Apache-2.0

Welcome to pyease's documentation!
==================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

.. toctree::
   :maxdepth: 3
   :caption: API reference

   code/modules



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
